<?php
/**
 * Echoes functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Echoes
 */

if ( ! function_exists( 'echoes_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function echoes_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on echoes, use a find and replace
		 * to change 'echoes' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'echoes', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'echoes-recent', 140, 90, true );
		add_image_size( 'echoes-post', 448, 233, true );

		set_post_thumbnail_size( 1024, 510, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'echoes' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5', array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			)
		);

		// Post format.
		add_theme_support(
			'post-formats',
			array(
				'video',
				'audio',
				'quote',
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add theme support for custom logo.
		add_theme_support(
			'custom-logo', array(
				'height'      => 70,
				'width'       => 300,
				'flex-height' => true,
				'flex-width'  => true,
			)
		);

		// Add theme support for custom background.
		$args = array(
			'default-color' => 'ffffff',
			'default-image' => '',
		);
		add_theme_support( 'custom-background', $args );

	}
endif;
add_action( 'after_setup_theme', 'echoes_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function echoes_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'echoes_content_width', 1024 );
}
add_action( 'after_setup_theme', 'echoes_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function echoes_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'echoes' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Main sidebar that appears on the right.', 'echoes' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer', 'echoes' ),
			'id'            => 'sidebar-2',
			'description'   => esc_html__( 'Appears in the footer section of the site.', 'echoes' ),
			'before_widget' => '<div><section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section></div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

}
add_action( 'widgets_init', 'echoes_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function echoes_scripts() {

	wp_enqueue_style( 'echoes-open-sans', 'https://fonts.googleapis.com/css?family=Open+Sans:400,700' );

	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/css/genericons.css', '', '4.3.0' );

	wp_enqueue_style( 'echoes-style', get_stylesheet_uri() );

	wp_enqueue_script( 'echoes-script', get_template_directory_uri() . '/js/script.js', array( 'jquery' ), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'echoes_scripts' );

/**
 * Pagination
 */

function echoes_numeric_posts_nav() {
 
    if( is_single() )
        return;
 
	the_posts_pagination( 
		array(
			'mid_size' => 2,
			'prev_text' => __( 'Previous', 'echoes' ),
			'next_text' => __( 'Next', 'echoes' ),
	) );
 
}

/**
 * Add editor style.
 */
function echoes_add_editor_styles() {
	add_editor_style(
		array(
			'css/editor-style.css',
			get_template_directory_uri() . '/css/genericons.css',
		)
	);
}
add_action( 'init', 'echoes_add_editor_styles' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

